import Vue from 'vue'
import Router from "vue-router";
import routes from "../config/routes";
import AuthDao from "@/dao/auth";
import SsoDao from "@/dao/sso";

import store from '../store'
// 注册路由
Vue.use(Router);

// 解决路由未跳转就点击其他路由报错
const originalPush = Router.prototype.push;
const originalReplace = Router.prototype.replace;
Router.prototype.push = function push(location, onResolve, onReject) {
    if (onResolve || onReject)
        return originalPush.call(this, location, onResolve, onReject);
    return originalPush.call(this, location).catch((err) => err);
};
Router.prototype.replace = function push(location, onResolve, onReject) {
    if (onResolve || onReject)
        return originalReplace.call(this, location, onResolve, onReject);
    return originalReplace.call(this, location).catch((err) => err);
};

// 配置路由
const router = new Router({
    routes: [
        {
            path: "*",
            name: "404",
            component: (resolve) => require(["@/views/404/index"], resolve),
        },
        ...routes,
    ],
});

// 路由白名单
const whiteList = ["/situation/cameraView", "/analysis/reportPreview"];

// 全局路由守卫
router.beforeEach((to, from, next) => {
    if (whiteList.includes(to.path)) {
        next();
        return;
    }
    const parentId = map_config.SYS_ID;
    //针对济南特殊处理：根据url中得tokenId，进行base32加密用户名和密码，然后请求登录接口获取token
    const urls = location.href;
    let tokenId = "";
    if (urls.indexOf("?") != -1) {
        // const arr = urls.split("?");
        // const search = arr[arr.length - 1];
        // const params = search.split("&");
        // params.forEach(val => {
        //     const temp = val.split("=");
        //     if(temp[0]=="tokenId" && temp[1]!=null){
        //         tokenId=temp[1];
        //     }
        // });
        let arr = urls.split('?')
        let paramsArr = arr[1].split('&')
        let resObj = paramsArr.reduce((a, b) => {
            let [key, value] = b.split('=')
            a[key] = value
            return a
        }, {})
        tokenId = resObj.tokenId

        // 读取params的 center&zoom 并存储store
        if (resObj.lon && resObj.lat) {
            store.commit('setCenter', [Number(resObj.lon), Number(resObj.lat)])
        }
        if (resObj.zoom) {
            store.commit('setZoom', Number(resObj.zoom))
        }
    }
    if (tokenId) {
        let base32 = require('base32');
        //alert('basetokenId:'+base32.encode("haixin;haixin123").toUpperCase());
        let tokenStr = base32.decode(tokenId.toLowerCase());
        // alert("tokenId..."+tokenStr);
        SsoDao.login({
            data: {
                username: tokenStr.split(';')[0],
                password: tokenStr.split(';')[1]
            }
        }).then((res) => {
            if (res.data.status === "success") {
                AuthDao.queryMenu({
                    params: {
                        parentId,
                        isRecursion: true,
                    },
                }).then((res) => {
                    let routes = res.data.content;
                    for (let route of routes) {
                        if (route.url === to.path) {
                            next();
                        }
                    }
                });
            } else {
                if (res.data.code == "10401") {
                    this.$refs.user_authorization.getPage(res.data);
                } else {
                    __.url.redirectToLogin();
                }
            }
        });
    } else {
        AuthDao.queryMenu({
            params: {
                parentId,
                isRecursion: true,
            },
        }).then((res) => {
            let routes = res.data.content;
            for (let route of routes) {
                if (route.url === to.path) {
                    next();
                }
            }
        });

    }
});
router.afterEach((to, from) => {
    store.commit("setPathActive", to.fullPath);
})
export default router;
